summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/config.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/config.h b/include/config.h
index ad772033d..7e19ba32f 100644
--- a/include/config.h
+++ b/include/config.h
@@ -550,8 +550,8 @@ class CoreExport ServerConfig
time_t NSKill;
/* Modes set on a user when they identify */
Anope::string NSModesOnID;
- /* Restore nick/channels on ghost */
- bool NSRestoreOnGhost;
+ /* Restore nick/channels on recover */
+ bool NSRestoreOnRecover;
/* Whether or not to use SASL */
bool NSSASL;